@@ -49,8 +49,8 @@ class SparkPipelineFrameworkTestRunner:
         apply_schema_to_output: bool = True,
         check_output: bool = True,
         ignore_views_for_output: Optional[List[str]] = None,
-        input_schema: Optional[StructType] = None,
-        output_schema: Optional[StructType] = None,
+        input_schema: Optional[Union[StructType, Dict[str, StructType]]] = None,
+        output_schema: Optional[Union[StructType, Dict[str, StructType]]] = None,
     ) -> None:
         """
         Tests Spark Transformers without writing any code
@@ -77,7 +77,10 @@ class SparkPipelineFrameworkTestRunner:
         :param apply_schema_to_output: If true applies schema to output file
         :param check_output: if set, check the output of the test.  Otherwise don't check the output.
         :param ignore_views_for_output: list of view names to ignore when writing output schema and output json
-        :param input_schema: Optional input_schema to apply to the input data
+        :param input_schema: Optional input_schema to apply to the input data. Can be a schema or a dictionary
+                                of schemas where the key is name of the view
+        :param output_schema: Optional output_schema to apply to the input data. Can be a schema or a dictionary
+                                of schemas where the key is name of the view
         :return: Throws SparkPipelineFrameworkTestingException if there are mismatches between
                     expected output files and actual output files.  The `exceptions` list in
                     SparkPipelineFrameworkTestingException holds all the mismatch exceptions
@@ -90,6 +93,7 @@ class SparkPipelineFrameworkTestRunner:
 
         # first clear any stuff in SparkSession
         clean_spark_session(session=spark_session)
+        input_table_names: List[str] = []
 
         # for each of them
         testable_folder: str
@@ -118,7 +122,7 @@ class SparkPipelineFrameworkTestRunner:
             # write out any input schemas
             input_tables: List[Table] = spark_session.catalog.listTables("default")
 
-            input_table_names: List[str] = [
+            input_table_names = [
                 t.name for t in input_tables if not t.name.startswith("expected_")
             ]
             if not input_schema:
@@ -133,137 +137,133 @@ class SparkPipelineFrameworkTestRunner:
                         schema_folder=input_schema_folder,
                     )
 
-            # read parameters.json if it exists
-            parameters_json_file: Path = Path(testable_folder).joinpath(
-                "parameters.json"
+        # read parameters.json if it exists
+        parameters_json_file: Path = Path(folder_path).joinpath("parameters.json")
+        if os.path.exists(parameters_json_file):
+            with open(parameters_json_file, "r") as file:
+                parameters = json.loads(file.read())
+                assert parameters
+
+        # turn path into transformer name and call transformer
+        # first set the view parameter since AutoMapper transformers require it
+        if "view" not in parameters:
+            destination_view_name: str = "output"
+            parameters["view"] = destination_view_name
+
+        # find name of transformer and run it
+        search_result: Optional[Match[str]] = search(r"/library/", str(folder_path))
+        if search_result:
+            SparkPipelineFrameworkTestRunner.run_transformer(
+                spark_session=spark_session,
+                parameters=parameters,
+                search_result=search_result,
+                testable_folder=str(folder_path),
+                transformer_type=transformer_type,
             )
-            if os.path.exists(parameters_json_file):
-                with open(parameters_json_file, "r") as file:
-                    parameters = json.loads(file.read())
-                    assert parameters
 
-            # turn path into transformer name and call transformer
-            # first set the view parameter since AutoMapper transformers require it
-            if "view" not in parameters:
-                destination_view_name: str = "output"
-                parameters["view"] = destination_view_name
+        if check_output:
+            # write out any missing schemas
+            output_tables: List[Table] = spark_session.catalog.listTables("default")
 
-            # find name of transformer and run it
-            search_result: Optional[Match[str]] = search(r"/library/", testable_folder)
-            if search_result:
-                SparkPipelineFrameworkTestRunner.run_transformer(
-                    spark_session=spark_session,
-                    parameters=parameters,
-                    search_result=search_result,
-                    testable_folder=testable_folder,
-                    transformer_type=transformer_type,
-                )
-
-            if check_output:
-                # write out any missing schemas
-                output_tables: List[Table] = spark_session.catalog.listTables("default")
-
-                if ignore_views_for_output is not None:
-                    output_tables = [
-                        table
-                        for table in output_tables
-                        if table.name not in ignore_views_for_output
-                    ]
-
-                output_schema_folder: Path = Path(testable_folder).joinpath(
-                    "output_schema"
-                )
-                tables_for_writing_schema: List[str] = [
-                    t.name
-                    for t in output_tables
-                    if not t.name.startswith("expected_")
-                    and t.name not in input_table_names
+            if ignore_views_for_output is not None:
+                output_tables = [
+                    table
+                    for table in output_tables
+                    if table.name not in ignore_views_for_output
                 ]
-                if (
-                    "output" in tables_for_writing_schema
-                ):  # if there is an output table then ignore other input_tables
-                    tables_for_writing_schema = ["output"]
 
-                if not input_schema:
-                    for table_name in tables_for_writing_schema:
-                        if not os.path.exists(output_schema_folder):
-                            os.mkdir(output_schema_folder)
+            output_schema_folder: Path = Path(folder_path).joinpath("output_schema")
+            tables_for_writing_schema: List[str] = [
+                t.name
+                for t in output_tables
+                if not t.name.startswith("expected_")
+                and t.name not in input_table_names
+            ]
+            if (
+                "output" in tables_for_writing_schema
+            ):  # if there is an output table then ignore other input_tables
+                tables_for_writing_schema = ["output"]
 
-                        SparkPipelineFrameworkTestRunner.write_schema_to_output(
-                            spark_session=spark_session,
-                            view_name=table_name,
-                            schema_folder=output_schema_folder,
-                        )
+            if not output_schema:
+                for table_name in tables_for_writing_schema:
+                    if not os.path.exists(output_schema_folder):
+                        os.mkdir(output_schema_folder)
 
-                # for each file in output folder, loading into a view in Spark (prepend with "expected_")
-                output_folder = Path(testable_folder).joinpath("output")
-                if not os.path.exists(output_folder):
-                    os.mkdir(output_folder)
-                output_files = [
-                    f for f in listdir(output_folder) if isfile(join(output_folder, f))
-                ]
-                views_found: List[str] = []
-                if not temp_folder:
-                    temp_folder = output_folder.joinpath("temp")
-
-                if os.path.exists(temp_folder):
-                    shutil.rmtree(temp_folder)
-
-                data_frame_exceptions: List[SparkDataFrameComparerException] = []
-                for output_file in output_files:
-                    found_output_file: bool
-                    data_frame_exception: Optional[SparkDataFrameComparerException]
-                    (
-                        found_output_file,
-                        data_frame_exception,
-                    ) = SparkPipelineFrameworkTestRunner.process_output_file(
-                        spark_session=spark_session,
-                        output_file=output_file,
-                        output_folder=output_folder,
-                        output_schema_folder=output_schema_folder,
-                        temp_folder=temp_folder.joinpath("result"),
-                        func_path_modifier=func_path_modifier,
-                        sort_output_by=sort_output_by,
-                        apply_schema_to_output=apply_schema_to_output,
-                        output_schema=output_schema,
-                    )
-                    if found_output_file:
-                        views_found.append(
-                            SparkPipelineFrameworkTestRunner.get_view_name_from_file_path(
-                                output_file
-                            ).lower()
-                        )
-                        if data_frame_exception:
-                            data_frame_exceptions.append(data_frame_exception)
-
-                # write out any missing output files
-                table_names_to_write_to_output: List[str] = [
-                    t.name
-                    for t in output_tables
-                    if t.name.lower() not in views_found
-                    and not t.name.startswith("expected_")
-                    and t.name not in input_table_names
-                ]
-                if (
-                    "output" in table_names_to_write_to_output
-                ):  # if there is an output table then ignore other input_tables
-                    table_names_to_write_to_output = ["output"]
-                for table_name in table_names_to_write_to_output:
-                    SparkPipelineFrameworkTestRunner.write_table_to_output(
+                    SparkPipelineFrameworkTestRunner.write_schema_to_output(
                         spark_session=spark_session,
                         view_name=table_name,
-                        output_folder=output_folder,
-                        temp_folder=temp_folder.joinpath("result"),
-                        sort_output_by=sort_output_by,
-                        output_as_json_only=output_as_json_only,
+                        schema_folder=output_schema_folder,
                     )
 
-                clean_spark_session(session=spark_session)
+            # for each file in output folder, loading into a view in Spark (prepend with "expected_")
+            output_folder = Path(folder_path).joinpath("output")
+            if not os.path.exists(output_folder):
+                os.mkdir(output_folder)
+            output_files = [
+                f for f in listdir(output_folder) if isfile(join(output_folder, f))
+            ]
+            views_found: List[str] = []
+            if not temp_folder:
+                temp_folder = output_folder.joinpath("temp")
 
-                if len(data_frame_exceptions) > 0:
-                    raise SparkPipelineFrameworkTestingException(
-                        exceptions=data_frame_exceptions
+            if os.path.exists(temp_folder):
+                shutil.rmtree(temp_folder)
+
+            data_frame_exceptions: List[SparkDataFrameComparerException] = []
+            for output_file in output_files:
+                found_output_file: bool
+                data_frame_exception: Optional[SparkDataFrameComparerException]
+                (
+                    found_output_file,
+                    data_frame_exception,
+                ) = SparkPipelineFrameworkTestRunner.process_output_file(
+                    spark_session=spark_session,
+                    output_file=output_file,
+                    output_folder=output_folder,
+                    output_schema_folder=output_schema_folder,
+                    temp_folder=temp_folder.joinpath("result"),
+                    func_path_modifier=func_path_modifier,
+                    sort_output_by=sort_output_by,
+                    apply_schema_to_output=apply_schema_to_output,
+                    output_schema=output_schema,
+                )
+                if found_output_file:
+                    views_found.append(
+                        SparkPipelineFrameworkTestRunner.get_view_name_from_file_path(
+                            output_file
+                        ).lower()
                     )
+                    if data_frame_exception:
+                        data_frame_exceptions.append(data_frame_exception)
+
+            # write out any missing output files
+            table_names_to_write_to_output: List[str] = [
+                t.name
+                for t in output_tables
+                if t.name.lower() not in views_found
+                and not t.name.startswith("expected_")
+                and t.name not in input_table_names
+            ]
+            if (
+                "output" in table_names_to_write_to_output
+            ):  # if there is an output table then ignore other input_tables
+                table_names_to_write_to_output = ["output"]
+            for table_name in table_names_to_write_to_output:
+                SparkPipelineFrameworkTestRunner.write_table_to_output(
+                    spark_session=spark_session,
+                    view_name=table_name,
+                    output_folder=output_folder,
+                    temp_folder=temp_folder.joinpath("result"),
+                    sort_output_by=sort_output_by,
+                    output_as_json_only=output_as_json_only,
+                )
+
+            clean_spark_session(session=spark_session)
+
+            if len(data_frame_exceptions) > 0:
+                raise SparkPipelineFrameworkTestingException(
+                    exceptions=data_frame_exceptions
+                )
 
     @staticmethod
     def run_transformer(
@@ -315,7 +315,7 @@ class SparkPipelineFrameworkTestRunner:
         func_path_modifier: Optional[Callable[[Union[Path, str]], Union[Path, str]]],
         sort_output_by: Optional[List[str]],
         apply_schema_to_output: bool,
-        output_schema: Optional[StructType],
+        output_schema: Optional[Union[StructType, Dict[str, StructType]]],
         temp_folder: Optional[Union[Path, str]] = None,
     ) -> Tuple[bool, Optional[SparkDataFrameComparerException]]:
         data_frame_exception: Optional[SparkDataFrameComparerException] = None
@@ -336,158 +336,140 @@ class SparkPipelineFrameworkTestRunner:
             else []
         )
 
-        found_output_file: bool = False
+        found_output_file: bool
         output_file_path = os.path.join(output_folder, output_file)
         result_path: Optional[Path] = (
             Path(temp_folder).joinpath(f"{view_name}") if temp_folder else None
         )
-        result_file: Optional[Path] = None
-        output_schema_file: Optional[str] = None
-        if file_extension.lower() == ".csv":
-            output_schema_file = os.path.join(output_schema_folder, f"{view_name}.json")
-            # if we have an output schema file use it
-            if (
-                apply_schema_to_output
-                and not output_schema
-                and os.path.exists(output_schema_file)
-            ):
-                with open(output_schema_file) as file:
-                    schema_json = json.loads(file.read())
-                schema = StructType.fromJson(schema_json)
-                print(
-                    f"Reading file {output_file_path} using schema: {output_schema_file}"
-                )
-                spark_session.read.schema(schema).csv(
-                    path=output_file_path, header=True, comment="#", emptyValue=None
-                ).createOrReplaceTempView(f"expected_{view_name}")
-            elif apply_schema_to_output and output_schema:
-                print(f"Reading file {output_file_path} using passed in schema")
-                spark_session.read.schema(output_schema).csv(
-                    path=output_file_path, header=True, comment="#", emptyValue=None
-                ).createOrReplaceTempView(f"expected_{view_name}")
-            else:  # if we don't have schema file then load without a schema
-                spark_session.read.csv(
-                    path=output_file_path, header=True, comment="#", emptyValue=None
-                ).createOrReplaceTempView(f"expected_{view_name}")
 
-            # write the result file to temp folder
-            if result_path and temp_folder:
-                result_path_for_view: Path = result_path.joinpath(f"{view_name}.csv")
-                if len(sort_columns) > 0:
-                    result_df.coalesce(1).sort(*sort_columns).write.csv(
-                        path=str(result_path_for_view), header=True
-                    )
-                else:
-                    result_df.coalesce(1).write.csv(
-                        path=str(result_path_for_view), header=True
-                    )
-                if output_schema:
-                    # read result_df with output schema so it has all the columns
-                    result_df = result_df.sql_ctx.read.schema(output_schema).csv(
-                        str(result_path_for_view), header=True
-                    )
-                result_file = Path(temp_folder).joinpath(f"{view_name}.csv")
+        # get schema
+        output_schema_for_view: Optional[StructType] = None
+        output_schema_file: str = os.path.join(
+            output_schema_folder, f"{view_name}.json"
+        )
+        # if there is a schema file and no schema was passed in then use that
+        if (
+            apply_schema_to_output
+            and not output_schema
+            and os.path.exists(output_schema_file)
+        ):
+            with open(output_schema_file) as file:
+                schema_json = json.loads(file.read())
+            output_schema_for_view = StructType.fromJson(schema_json)
+            print(f"Reading file {output_file_path} using schema: {output_schema_file}")
+        elif apply_schema_to_output and output_schema:
+            print(
+                f"Reading file {output_file_path} using passed in schema for view {view_name}"
+            )
+            # the schema is passed either as a single schema or a dict of schemas
+            output_schema_for_view = (
+                output_schema[view_name]  # type: ignore
+                if output_schema
+                and isinstance(output_schema, dict)
+                and view_name in output_schema
+                else output_schema
+            )
+
+        # create a reader to read the file (using schema if specified)
+        reader = (
+            spark_session.read.schema(output_schema_for_view)
+            if output_schema_for_view
+            else spark_session.read
+        )
+
+        # now read the file using the reader for the file extension
+        output_df: DataFrame
+        if file_extension.lower() == ".csv":
+            output_df = reader.csv(
+                path=output_file_path, header=True, comment="#", emptyValue=None
+            )
+            found_output_file = True
+        elif file_extension.lower() == ".jsonl" or file_extension.lower() == ".json":
+            output_df = reader.option("multiLine", True).json(path=output_file_path)
+            found_output_file = True
+        elif file_extension.lower() == ".parquet":
+            output_df = reader.parquet(path=output_file_path)
+            found_output_file = True
+        else:
+            assert False, f"Unsupported file extension: {file_extension}"
+
+        # create expected view
+        output_df.createOrReplaceTempView(f"expected_{view_name}")
+
+        # write result to temp folder for comparison
+        if result_path and temp_folder:
+            result_path_for_view = result_path.joinpath(f"{view_name}.json")
+            result_df = (
+                result_df.coalesce(1).sort(*sort_columns)
+                if len(sort_columns) > 0
+                else result_df.coalesce(1)
+            )
+            result_df.write.json(path=str(result_path_for_view))
+            if output_schema and output_schema_for_view:
+                result_df = result_df.sql_ctx.read.schema(output_schema_for_view).json(
+                    str(result_path_for_view)
+                )
+            result_file: Path = Path(temp_folder).joinpath(f"{view_name}.json")
+            if file_extension.lower() == ".csv":
                 SparkPipelineFrameworkTestRunner.combine_spark_csv_files_to_one_file(
                     source_folder=result_path_for_view,
                     destination_file=result_file,
                     file_extension="csv",
                 )
-
-            found_output_file = True
-        elif file_extension.lower() == ".jsonl" or file_extension.lower() == ".json":
-            output_schema_file = os.path.join(output_schema_folder, output_file)
-            if (
-                apply_schema_to_output
-                and not output_schema
-                and os.path.exists(output_schema_file)
+            elif (
+                file_extension.lower() == ".jsonl" or file_extension.lower() == ".json"
             ):
-                with open(output_schema_file) as file:
-                    schema_json = json.loads(file.read())
-                schema = StructType.fromJson(schema_json)
-                print(
-                    f"Reading file {output_file_path} using schema: {output_schema_file}"
-                )
-                spark_session.read.schema(schema).option("multiLine", True).json(
-                    path=output_file_path
-                ).createOrReplaceTempView(f"expected_{view_name}")
-            elif apply_schema_to_output and output_schema:
-                print(f"Reading file {output_file_path} using passed in schema")
-                spark_session.read.schema(output_schema).option("multiLine", True).json(
-                    path=output_file_path
-                ).createOrReplaceTempView(f"expected_{view_name}")
-            else:
-                spark_session.read.option("multiLine", True).json(
-                    path=output_file_path
-                ).createOrReplaceTempView(f"expected_{view_name}")
-            # write result to temp folder for comparison
-            if result_path and temp_folder:
-                result_path_for_view = result_path.joinpath(f"{view_name}.json")
-                if len(sort_columns) > 0:
-                    result_df.coalesce(1).sort(*sort_columns).write.json(
-                        path=str(result_path_for_view)
-                    )
-                else:
-                    result_df.coalesce(1).write.json(path=str(result_path_for_view))
-                if output_schema:
-                    # read result_df with output schema so it has all the columns
-                    result_df = result_df.sql_ctx.read.schema(output_schema).json(
-                        str(result_path_for_view)
-                    )
-                result_file = Path(temp_folder).joinpath(f"{view_name}.json")
                 SparkPipelineFrameworkTestRunner.combine_spark_json_files_to_one_file(
                     source_folder=result_path_for_view,
                     destination_file=result_file,
                     file_extension="json",
                 )
-            found_output_file = True
-        elif file_extension.lower() == ".parquet":
-            spark_session.read.parquet(path=output_file_path).createOrReplaceTempView(
-                f"expected_{view_name}"
-            )
-            found_output_file = True
-        if found_output_file:
-            # Do a data frame compare on each view
-            print(f"Comparing with view:[view_name= with view:[expected_{view_name}]")
-            try:
-                # drop any corrupted column
-                assert_compare_data_frames(
-                    expected_df=spark_session.table(f"expected_{view_name}").drop(
-                        "_corrupt_record"
-                    ),
-                    result_df=result_df,
-                    result_path=result_file,
-                    expected_path=output_file_path,
-                    temp_folder=temp_folder,
-                    func_path_modifier=func_path_modifier,
-                    order_by=sort_columns if len(sort_columns) > 0 else None,
+
+            if found_output_file:
+                # Do a data frame compare on each view
+                print(
+                    f"Comparing with view:[view_name= with view:[expected_{view_name}]"
                 )
-            except SparkDataFrameComparerException as e:
-                data_frame_exception = e
-                # for schema errors, show a compare path for schema
-                if e.exception_type == ExceptionType.SchemaMismatch:
-                    if temp_folder and output_schema_file:
-                        # write the new schema to temp folder
-                        result_schema_path = (
-                            SparkPipelineFrameworkTestRunner.write_schema_to_output(
-                                spark_session=spark_session,
-                                view_name=view_name,
-                                schema_folder=Path(temp_folder)
-                                .joinpath("schemas")
-                                .joinpath("result")
-                                .joinpath(view_name),
+                try:
+                    # drop any corrupted column
+                    assert_compare_data_frames(
+                        expected_df=spark_session.table(f"expected_{view_name}").drop(
+                            "_corrupt_record"
+                        ),
+                        result_df=result_df,
+                        result_path=result_file,
+                        expected_path=output_file_path,
+                        temp_folder=temp_folder,
+                        func_path_modifier=func_path_modifier,
+                        order_by=sort_columns if len(sort_columns) > 0 else None,
+                    )
+                except SparkDataFrameComparerException as e:
+                    data_frame_exception = e
+                    # for schema errors, show a compare path for schema
+                    if e.exception_type == ExceptionType.SchemaMismatch:
+                        if temp_folder and output_schema_file:
+                            # write the new schema to temp folder
+                            result_schema_path = (
+                                SparkPipelineFrameworkTestRunner.write_schema_to_output(
+                                    spark_session=spark_session,
+                                    view_name=view_name,
+                                    schema_folder=Path(temp_folder)
+                                    .joinpath("schemas")
+                                    .joinpath("result")
+                                    .joinpath(view_name),
+                                )
                             )
-                        )
-                        e.compare_path = (
-                            SparkPipelineFrameworkTestRunner.get_compare_path(
-                                result_path=result_schema_path,
-                                expected_path=Path(output_schema_file),
-                                temp_folder=temp_folder,
-                                func_path_modifier=func_path_modifier,
-                                type_="schema",
+                            e.compare_path = (
+                                SparkPipelineFrameworkTestRunner.get_compare_path(
+                                    result_path=result_schema_path,
+                                    expected_path=Path(output_schema_file),
+                                    temp_folder=temp_folder,
+                                    func_path_modifier=func_path_modifier,
+                                    type_="schema",
+                                )
                             )
-                        )
-                        if func_path_modifier and e.compare_path:
-                            e.compare_path = func_path_modifier(e.compare_path)
+                            if func_path_modifier and e.compare_path:
+                                e.compare_path = func_path_modifier(e.compare_path)
 
         return found_output_file, data_frame_exception
 
@@ -503,7 +485,8 @@ class SparkPipelineFrameworkTestRunner:
         if expected_path and result_path and temp_folder:
             expected_file_name: str = os.path.basename(expected_path)
             # create a temp file to launch the diff tool
-            # use .command: https://stackoverflow.com/questions/5125907/how-to-run-a-shell-script-in-os-x-by-double-clicking
+            # use .command:
+            # https://stackoverflow.com/questions/5125907/how-to-run-a-shell-script-in-os-x-by-double-clicking
             compare_sh_path = Path(temp_folder).joinpath(
                 f"compare_{type_}_{expected_file_name}.command"
             )
@@ -522,53 +505,60 @@ class SparkPipelineFrameworkTestRunner:
         input_file: str,
         input_folder: Path,
         input_schema_folder: Path,
-        input_schema: Optional[StructType],
+        input_schema: Optional[Union[StructType, Dict[str, StructType]]],
     ) -> None:
         file_extension: str = (
             SparkPipelineFrameworkTestRunner.get_file_extension_from_file_path(
                 input_file
             )
         )
+        if file_extension.lower() not in [".csv", ".json", ".jsonl", ".parquet"]:
+            return
+
         view_name: str = SparkPipelineFrameworkTestRunner.get_view_name_from_file_path(
             input_file
         )
+
+        input_file_path = os.path.join(input_folder, input_file)
+
+        # get schema
+        input_schema_for_view: Optional[StructType] = None
+        input_schema_file: str = os.path.join(input_schema_folder, f"{view_name}.json")
+        # if there is a schema file and no schema was passed in then use that
+        if not input_schema and os.path.exists(input_schema_file):
+            with open(input_schema_file, "r") as file:
+                schema_json = json.loads(file.read())
+            input_schema_for_view = StructType.fromJson(schema_json)
+            print(f"Reading file {input_file_path} using schema: {input_schema_file}")
+        elif input_schema:
+            print(
+                f"Reading file {input_file_path} using passed in schema for view {view_name}"
+            )
+            # the schema is passed either as a single schema or a dict of schemas
+            input_schema_for_view = (
+                input_schema[view_name]  # type: ignore
+                if input_schema
+                and isinstance(input_schema, dict)
+                and view_name in input_schema
+                else input_schema
+            )
+
+        # create a reader to read the file (using schema if specified)
+        reader = (
+            spark_session.read.schema(input_schema_for_view)
+            if input_schema_for_view
+            else spark_session.read
+        )
+
+        input_df: DataFrame
         if file_extension.lower() == ".csv":
-            input_file_path = os.path.join(input_folder, input_file)
-            input_schema_file = os.path.join(input_schema_folder, f"{view_name}.json")
-            if os.path.exists(input_schema_file):
-                with open(input_schema_file) as file:
-                    schema_json: Dict[str, Any] = json.loads(file.read())
-                schema = StructType.fromJson(schema_json)
-                print(f"Reading file {input_file} using schema: {input_schema_file}")
-                spark_session.read.schema(schema).csv(
-                    path=input_file_path,
-                    header=True,
-                    comment="#",
-                    emptyValue=None,
-                ).limit(
-                    SparkPipelineFrameworkTestRunner.row_limit
-                ).createOrReplaceTempView(
-                    view_name
-                )
-                assert (
-                    "_corrupt_record" not in spark_session.table(view_name).columns
-                ), input_file_path
-            else:
-                spark_session.read.csv(
-                    path=input_file_path,
-                    header=True,
-                    comment="#",
-                    emptyValue=None,
-                ).limit(
-                    SparkPipelineFrameworkTestRunner.row_limit
-                ).createOrReplaceTempView(
-                    view_name
-                )
-                assert (
-                    "_corrupt_record" not in spark_session.table(view_name).columns
-                ), input_file_path
+            input_df = reader.csv(
+                path=input_file_path,
+                header=True,
+                comment="#",
+                emptyValue=None,
+            ).limit(SparkPipelineFrameworkTestRunner.row_limit)
         elif file_extension.lower() == ".jsonl" or file_extension.lower() == ".json":
-            input_file_path = os.path.join(input_folder, input_file)
             # create json_input_folder if it does not exist
             json_input_folder = os.path.join(input_folder, "..", "input_jsonl")
             if not os.path.exists(json_input_folder):
@@ -578,51 +568,21 @@ class SparkPipelineFrameworkTestRunner:
             convert_json_to_jsonl(
                 src_file=Path(input_file_path), dst_file=Path(jsonl_input_file_path)
             )
-            # find schema file
-            input_schema_file = os.path.join(input_schema_folder, input_file)
-            # if schema exists then use it when loading the file
-            if not input_schema and os.path.exists(input_schema_file):
-                with open(input_schema_file) as file:
-                    schema_json = json.loads(file.read())
-                schema = StructType.fromJson(schema_json)
-                print(f"Reading file {input_file} using schema: {input_schema_file}")
-                spark_session.read.schema(schema).json(
-                    path=jsonl_input_file_path
-                ).limit(
-                    SparkPipelineFrameworkTestRunner.row_limit
-                ).createOrReplaceTempView(
-                    view_name
-                )
-                assert (
-                    "_corrupt_record" not in spark_session.table(view_name).columns
-                ), input_file_path
-            elif input_schema:
-                print(f"Reading file {input_file} using passed in schema")
-                spark_session.read.schema(input_schema).json(
-                    path=jsonl_input_file_path
-                ).limit(
-                    SparkPipelineFrameworkTestRunner.row_limit
-                ).createOrReplaceTempView(
-                    view_name
-                )
-                assert (
-                    "_corrupt_record" not in spark_session.table(view_name).columns
-                ), input_file_path
-            else:  # if no schema found just load the file
-                spark_session.read.json(path=jsonl_input_file_path).limit(
-                    SparkPipelineFrameworkTestRunner.row_limit
-                ).createOrReplaceTempView(view_name)
-                assert (
-                    "_corrupt_record" not in spark_session.table(view_name).columns
-                ), input_file_path
-        elif file_extension.lower() == ".parquet":
-            input_file_path = os.path.join(input_folder, input_file)
-            spark_session.read.parquet(path=input_file_path).limit(
+            input_df = reader.json(path=jsonl_input_file_path).limit(
                 SparkPipelineFrameworkTestRunner.row_limit
-            ).createOrReplaceTempView(view_name)
-            assert (
-                "_corrupt_record" not in spark_session.table(view_name).columns
-            ), input_file_path
+            )
+        elif file_extension.lower() == ".parquet":
+            input_df = reader.parquet(path=input_file_path).limit(
+                SparkPipelineFrameworkTestRunner.row_limit
+            )
+        else:
+            assert False, f"Unsupported file extension: {file_extension}"
+
+        # create expected view
+        input_df.createOrReplaceTempView(view_name)
+        assert (
+            "_corrupt_record" not in spark_session.table(view_name).columns
+        ), input_file_path
 
     @staticmethod
     def get_view_name_from_file_path(input_file: str) -> str:
